@@ -1,7 +1,9 @@
 """Plot data. There is only one main function plot. Check it's documentation for how to use it."""
 
 from __future__ import annotations
-from typing import Union
+from typing import cast
+from pathlib import Path
+from dataclasses import dataclass
 
 from typing_extensions import Literal
 
@@ -18,18 +20,59 @@ from . import paths
 # from IPython import get_ipython
 
 
+@dataclass
+class _GetLayouts:
+    """Plotly layouts. Use `fig.layout.update(get_layout.categorical_scatter(title="My title"))'"""
+
+    def general(self, title):
+        return {
+            "title": {
+                "text": title,
+                "x": 0.5,
+                "xanchor": "center",
+                "yanchor": "top",
+                "y": 0.9 if misc._JUPYTER else 0.95,
+            },
+            "titlefont": {"size": 28},
+            "font": {"size": 17},
+        }
+
+    def categorical_scatter(self, title):
+        return {
+            **self.general(title),
+            "margin": {"l": 320, "r": 150, "b": 180, "t": 130},
+            "titlefont": {"size": 34},
+            "font": {"size": 22},
+            "yaxis": {"tickfont": {"size": 18}, "ticksuffix": " ", "title": {"standoff": 20}},
+        }
+
+    def time_series(self, title, showlegend, yaxis="Values"):
+        return {
+            **self.general(title),
+            "yaxis": {"title": yaxis},
+            "showlegend": showlegend,
+            "legend_orientation": "h",
+            "hoverlabel": {"namelength": -1},
+            "margin": {"l": 160, "r": 130, "b": 160, "t": 110},
+        }
+
+
+get_layout = _GetLayouts()
+
+
 def plot(
     complete_dataframe,
     plot_library: Literal["plotly", "matplotlib"] = "plotly",
-    plot_name: str = "Plot",
+    title: str = "Plot",
     legend: bool = True,
+    y_axis_name="Values",
     highlighted_column="",
     surrounded_column="",
-    grey_area: bool = False,
-    save: bool = False,
+    grey_area: None | list[str] = None,
+    save: None | Path | str = None,
     return_div: bool = False,
     show: bool = True,
-) -> Union[None, str]:
+) -> None | str:
     """Plots the data. Plotly or matplotlib can be used. It is possible to highlite two columns with different formating.
     It is usually used for time series visualization, but it can be used for different use case of course.
 
@@ -39,17 +82,17 @@ def plot(
         legend (bool, optional): Whether display legend or not. Defaults to True.
         highlighted_column (str, optional): Column name that will be formatted differently (blue). Can be empty. Defaults to "".
         surrounded_column (str, optional): Column name that will be formatted differently (black, wider). And is surrounded by
-            grey_area. Can be empty (if grey_area is False). Defaults to "".
-        grey_area ((bool, list[str])), optional): Whether to show grey area surrounding the surrounded_column. Can be False,
-            or list of ['lower_bound_column', 'upper_bound_column']. Both columns has to be in complete_dataframe. Defaults to False.
-        save ((False, str), optional): Whether save the plot.  If False or "", do not save, if path as str, save to defined path,
-            if "DESKTOP" save to desktop. Defaults to "".
-        return_div ((bool, str), optional): If 'div', return html div with plot as string. If False, just plot and do not return.
+            grey_area. Can be empty (if grey_area is None). Defaults to "".
+        grey_area (None | list[str]), optional): Whether to show grey area surrounding the surrounded_column. Can be None,
+            or list of ['lower_bound_column', 'upper_bound_column']. Both columns has to be in complete_dataframe. Defaults to None.
+        save (None | Path | str, optional): Whether save the plot.  If False or "", do not save, if Path as str path, save to defined path.
+            If "DESKTOP" save to desktop. Defaults to None.
+        return_div (bool, optional): If True, return html div with plot as string. If False, just plot and do not return.
             Defaults to False.
         show (bool, optional): Can be evaluated, but not shown (testing reasons). Defaults to True.
 
     Returns:
-        str: Only if return_div is True, else None.
+        None | str: Only if return_div is True, else None.
 
     Examples:
         Plot dataframe with
@@ -103,10 +146,11 @@ def plot(
         graph_data = []
 
         if grey_area:
+            grey_area = cast(list, grey_area)
+
             lower_bound_column = grey_area[0]
             upper_bound_column = grey_area[1]
 
-        if grey_area:
             upper_bound = pl.graph_objs.Scatter(
                 name="Upper bound",
                 x=complete_dataframe.index,
@@ -191,27 +235,7 @@ def plot(
                     )
                 )
 
-        fig.layout.update(
-            yaxis=dict(title="Values"),
-            title={
-                "text": plot_name,
-                "x": 0.5,
-                "xanchor": "center",
-                "yanchor": "top",
-                "y": 0.9 if misc._JUPYTER else 0.95,
-            },
-            titlefont={"size": 28},
-            showlegend=True if legend else False,
-            legend_orientation="h",
-            hoverlabel={"namelength": -1},
-            font={"size": 17},
-            margin={
-                "l": 160,
-                "r": 130,
-                "b": 160,
-                "t": 110,
-            },
-        )
+        fig.layout.update(get_layout.time_series(title, legend, y_axis_name))
 
         if show:
             fig.show()
@@ -219,7 +243,7 @@ def plot(
         if save:
             fig.write_html(save)
 
-        if return_div == "div":
+        if return_div:
 
             fig.layout.update(
                 title=None,
